| get_MPMdag | R Documentation |
This function computes the Median Probability DAG Model estimate (MPM) from the MCMC output of learn_DAG
get_MPMdag(learnDAG_output)
learnDAG_output |
object of class |
Output of learn_dag function consists of S draws from the joint posterior of DAGs and DAG-parameters in a zero-mean Gaussian DAG-model;
see the documentation of learn_DAG for more details.
The Median Probability DAG Model estimate (MPM) is obtained by including all edges whose posterior probability exceeds 0.5.
The posterior probability of inclusion of u -> v is estimated as the frequency of DAGs visited by the MCMC which contain the directed edge u -> v;
see also function get_edgeprobs and the corresponding documentation.
The (q,q) adjacency matrix of the median probability DAG model
Federico Castelletti and Alessandro Mascaro
F. Castelletti and A. Mascaro (2026). BCDAG: An R package for Bayesian structural and Causal learning of Gaussian DAGs. Journal of Statistical Software, doi:10.18637/jss.v116.i05.
F. Castelletti and A. Mascaro (2021). Structural learning and estimation of joint causal effects among network-dependent variables. Statistical Methods and Applications, Advance publication
M.M. Barbieri and J.O. Berger (2004). Optimal predictive model selection. The Annals of Statistics 32 870-897
# Randomly generate a DAG and the DAG-parameters
q = 8
w = 0.2
set.seed(123)
DAG = rDAG(q = q, w = w)
outDL = rDAGWishart(n = 1, DAG = DAG, a = q, U = diag(1, q))
L = outDL$L; D = outDL$D
Sigma = solve(t(L))%*%D%*%solve(L)
# Generate observations from a Gaussian DAG-model
n = 200
X = mvtnorm::rmvnorm(n = n, sigma = Sigma)
# Run the MCMC (Set S = 5000 and burn = 1000 for better results)
out_mcmc = learn_DAG(S = 500, burn = 100, a = q, U = diag(1,q)/n, data = X, w = 0.1,
fast = TRUE, save.memory = FALSE)
# Produce the MPM DAG estimate
get_MPMdag(out_mcmc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.